pub enum ParsedHttpMessage {
Request(HttpRequest),
Response(HttpResponse),
}Expand description
Classification of parsed HTTP message
Variants
Implementations
Sourceimpl ParsedHttpMessage
impl ParsedHttpMessage
Sourcepub fn is_request(&self) -> bool
pub fn is_request(&self) -> bool
Returns true if this is a request
Sourcepub fn is_response(&self) -> bool
pub fn is_response(&self) -> bool
Returns true if this is a response
Sourcepub fn as_request(&self) -> Option<&HttpRequest>
pub fn as_request(&self) -> Option<&HttpRequest>
Get the request if this is a request, None otherwise
Sourcepub fn as_response(&self) -> Option<&HttpResponse>
pub fn as_response(&self) -> Option<&HttpResponse>
Get the response if this is a response, None otherwise