HTTP/1.x parsing utilities
Structs
- Http
Request - HTTP request parsed from any HTTP version
- Http
Response - HTTP response parsed from any HTTP version
Functions
- is_
http1_ request - Check if data starts with an HTTP/1.x request
- is_
http1_ response - Check if data starts with an HTTP/1.x response
- try_
finalize_ http1_ response - Finalize an HTTP/1.x response when the connection closes.
- try_
parse_ http1_ request - Try to parse an HTTP/1.x request, returning Some only if complete. This combines header parsing and body completeness checking in one pass.
- try_
parse_ http1_ response - Try to parse an HTTP/1.x response, returning Some only if complete. This combines header parsing and body completeness checking in one pass.